==> quarkus-devtools-common-1.3.4.Final-redhat-00001-sources.jar: io/quarkus/platform/descriptor/loader/json/QuarkusJsonPlatformDescriptorLoaderContext.java <==
package io.quarkus.platform.descriptor.loader.json;

import io.quarkus.platform.descriptor.loader.QuarkusPlatformDescriptorLoaderContext;
import io.quarkus.platform.tools.DefaultMessageWriter;
import io.quarkus.platform.tools.MessageWriter;
import java.io.InputStream;
import java.util.function.Function;

public abstract class QuarkusJsonPlatformDescriptorLoaderContext implements QuarkusPlatformDescriptorLoaderContext {

    protected final MessageWriter log;
    protected final ArtifactResolver artifactResolver;
    protected final ResourceLoader resourceLoader;

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver) {
        this(artifactResolver, new DefaultMessageWriter());
    }

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver, MessageWriter log) {
        this(artifactResolver, new ClassPathResourceLoader(Thread.currentThread().getContextClassLoader()), log);
    }

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver, ResourceLoader resourceLoader,
            MessageWriter log) {
        this.log = log;
        this.artifactResolver = artifactResolver;
        this.resourceLoader = resourceLoader;
    }

    public abstract <T> T parseJson(Function<InputStream, T> parser);

    @Override
    public MessageWriter getMessageWriter() {
        return log;
    }

    public ArtifactResolver getArtifactResolver() {
        return artifactResolver;
    }

    public ResourceLoader getResourceLoader() {
        return resourceLoader;
    }
}

==> quarkus-devtools-common-1.11.6.Final-redhat-00001-sources.jar: io/quarkus/platform/descriptor/loader/json/QuarkusJsonPlatformDescriptorLoaderContext.java <==
package io.quarkus.platform.descriptor.loader.json;

import io.quarkus.devtools.messagewriter.MessageWriter;
import io.quarkus.platform.descriptor.loader.QuarkusPlatformDescriptorLoaderContext;
import java.io.InputStream;
import java.util.function.Function;

public abstract class QuarkusJsonPlatformDescriptorLoaderContext implements QuarkusPlatformDescriptorLoaderContext {

    protected final MessageWriter log;
    protected final ArtifactResolver artifactResolver;
    protected final ResourceLoader resourceLoader;

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver) {
        this(artifactResolver, MessageWriter.info());
    }

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver, MessageWriter log) {
        this(artifactResolver, new ClassPathResourceLoader(Thread.currentThread().getContextClassLoader()), log);
    }

    public QuarkusJsonPlatformDescriptorLoaderContext(ArtifactResolver artifactResolver, ResourceLoader resourceLoader,
            MessageWriter log) {
        this.log = log;
        this.artifactResolver = artifactResolver;
        this.resourceLoader = resourceLoader;
    }

    public abstract <T> T parseJson(Function<InputStream, T> parser);

    @Override
    public MessageWriter getMessageWriter() {
        return log;
    }

    public ArtifactResolver getArtifactResolver() {
        return artifactResolver;
    }

    public ResourceLoader getResourceLoader() {
        return resourceLoader;
    }
}
